@@ -57,11 +57,26 @@ class BaseClient:
         retry_handlers: Optional[List[RetryHandler]] = None,
     ):
         self.token = None if token is None else token.strip()
+        """A string specifying an `xoxp-*` or `xoxb-*` token."""
         self.base_url = base_url
+        """A string representing the Slack API base URL.
+        Default is `'https://www.slack.com/api/'`."""
         self.timeout = timeout
+        """The maximum number of seconds the client will wait
+        to connect and receive a response from Slack.
+        Default is 30 seconds."""
         self.ssl = ssl
+        """An [`ssl.SSLContext`](https://docs.python.org/3/library/ssl.html#ssl.SSLContext)
+        instance, helpful for specifying your own custom
+        certificate chain."""
         self.proxy = proxy
+        """String representing a fully-qualified URL to a proxy through which
+        to route all requests to the Slack API. Even if this parameter
+        is not specified, if any of the following environment variables are
+        present, they will be loaded into this parameter: `HTTPS_PROXY`,
+        `https_proxy`, `HTTP_PROXY` or `http_proxy`."""
         self.headers = headers or {}
+        """`dict` representing additional request headers to attach to all requests."""
         self.headers["User-Agent"] = get_user_agent(
             user_agent_prefix, user_agent_suffix
         )
@@ -414,19 +429,25 @@ class BaseClient:
                 return resp
 
             except HTTPError as e:
-                resp = {"status": e.code, "headers": e.headers}
+                # As adding new values to HTTPError#headers can be ignored, building a new dict object here
+                response_headers = dict(e.headers.items())
+                resp = {"status": e.code, "headers": response_headers}
                 if e.code == 429:
                     # for compatibility with aiohttp
                     if (
-                        "retry-after" not in resp["headers"]
-                        and "Retry-After" in resp["headers"]
+                        "retry-after" not in response_headers
+                        and "Retry-After" in response_headers
                     ):
-                        resp["headers"]["retry-after"] = resp["headers"]["Retry-After"]
+                        response_headers["retry-after"] = response_headers[
+                            "Retry-After"
+                        ]
                     if (
-                        "Retry-After" not in resp["headers"]
-                        and "retry-after" in resp["headers"]
+                        "Retry-After" not in response_headers
+                        and "retry-after" in response_headers
                     ):
-                        resp["headers"]["Retry-After"] = resp["headers"]["retry-after"]
+                        response_headers["Retry-After"] = response_headers[
+                            "retry-after"
+                        ]
 
                 # read the response body here
                 charset = e.headers.get_content_charset() or "utf-8"
@@ -437,7 +458,7 @@ class BaseClient:
                 retry_request = RetryHttpRequest.from_urllib_http_request(req)
                 retry_response = RetryHttpResponse(
                     status_code=e.code,
-                    headers={k: [v] for k, v in e.headers.items()},
+                    headers={k: [v] for k, v in response_headers.items()},
                     data=response_body.encode("utf-8")
                     if response_body is not None
                     else None,
